diff src/gl-render.h @ 11576:8ac9687dbe9f

rename backend to graphics_toolkit
author John W. Eaton <jwe@octave.org>
date Thu, 20 Jan 2011 02:29:57 -0500
parents fd0a3ac60b0e
children cda4aa780d58
line wrap: on
line diff
--- a/src/gl-render.h	Wed Jan 19 21:16:13 2011 -0800
+++ b/src/gl-render.h	Thu Jan 20 02:29:57 2011 -0500
@@ -137,8 +137,8 @@
                                  bool filled) const;
 
 private:
-  // the backend associated with the figure being rendered
-  graphics_backend backend;
+  // The graphics toolkit associated with the figure being rendered.
+  graphics_toolkit toolkit;
 
   // axes transformation data
   graphics_xform xform;